@@ -1,4 +1,6 @@
-from sqlite3 import NotSupportedError
+from __future__ import annotations
+
+from sqlite3 import NotSupportedError  # TODO
 from typing import Sequence
 
 from .engine import Benchmarker, Engine, SimulBenchmarker, SimulEngine
