@@ -13,9 +13,25 @@ class Scorer:
 
     @property
     def perfect_score(self) -> int:
+        """A decimal representation of the perfect ternary score.
+
+        e.g. in a 5 letter game of Wordle, the perfect score is 22222.
+        Therefore, this method would return 242.
+
+        Returns:
+            int: Returns the perfect score.
+        """
         return (3**self.size) - 1
 
     def is_perfect_score(self, score: int) -> bool:
+        """Returns true if the score provided results in the game being won.
+
+        Args:
+            score (int): The decimal representation of a ternary number.
+
+        Returns:
+            bool: A bool denoting whether the score is a perfect score.
+        """
         return score == self.perfect_score
 
     def score_word(self, solution: Word, guess: Word) -> int:
